@@ -51,6 +51,6 @@ enum
 };
 
 extern int LastKey;
-extern int dokey (int);
+extern int km_dokey (int);
 
 #include <limits.h>
